@@ -79,12 +79,14 @@ class encryption:
 		}
 		b = ""
 		for i in string:
-			if i.lower() in code:
+			if i.isalpha() == True:
+				i = i.lower()
+			if i in code:
 				b += code[i]
 			else:
 				b += "#"
 			b += " "
-		return b
+		return b[:-1]
 
 	def tapCode(string):
 		code = {
@@ -117,6 +119,7 @@ class encryption:
 		}
 		c = ""
 		for i in string:
+			i = i.upper()
 			if i != " ":
 				c += code[i] + " "
 			else:
@@ -226,9 +229,9 @@ class decryption:
 			if ord(a) not in range (65,91) and ord(a) not in range (97,124):
 				c += a
 			elif a.isupper():
-				c += chr((ord(a) - k - 65) % 26 + 65)
+				c += chr((ord(a) - key - 65) % 26 + 65)
 			else:
-				c += chr((ord(a) - k - 97) % 26 + 97)
+				c += chr((ord(a) - key - 97) % 26 + 97)
 		return c
 
 	def vigenereCipher(string, key):
